All Classes and Interfaces
Class
Description
Base class for binding helpers.
Base class for all filters.
Abstract class that defines all the properties and behaviors a RippleGenerator should have.
Events class for RippleGenerators.
Convenience factory for various animations applied to
Nodes.Utility class to easily build animations of any sort.
Common base class for
Animations.ParallelBuilder and Animations.SequentialBuilder.Builder class for keyframes and keyvalues.
Implementation of
Animations.AbstractBuilder that uses a ParallelTransition as "main" animation.Builder class to easily create a
PauseTransition with fluent api.Implementation of
Animations.AbstractBuilder that uses a SequentialTransition as "main" animation.Builder class to easily create a
Timeline with fluent api.Simple immutable bean that has a node reference, a duration for the animation and
an action to perform when the animation ends.
Cubic Bezier implementation from https://github.com/gre/bezier-easing
Helper class for
BiBindingManager.Binding helper for bidirectional bindings.
This singleton class manages bidirectional bindings.
Simply an
ObjectProperty that wraps a BiConsumer.Simply an
ObjectProperty that wraps a BiFunction.Helper class for the
BindingManager.Binding helper for unidirectional bindings.
This singleton class manages unidirectional bindings.
A special
WeakHashMap that allows to retrieve the keys ordered by insertion.A simple immutable bean that wraps a
BiPredicate and a String that represents
the name for the predicate.Simply an
ObjectProperty that wraps a BiPredicate.Extension of
AbstractFilter for boolean fields.A
BooleanListBinding is a particular binding that takes a list of
BooleanProperty and observes each one of them updating its value
when they change.Enumeration to specify how two predicates should be chained.
This is the implementation of a circular FIFO queue.
Utils class for JavaFX's
Colors and CSS.Simply an
ObjectProperty that wraps a Comparator.Simply an
ObjectProperty that wraps a Consumer.A simple implementation of
Transition that allows to specify
what to do when the ConsumerTransition.interpolate(double) method is called by using
a Consumer.Convenience class to build
CornerRadii objects.JavaFX allows you to create custom
Bounds objects, see BoundingBox, the thing is
that it automatically computes the max X/Y/Z values.A
StringConverter capable of converting LocalDate to/from Strings.Utils class for Java's time API.
Simple bean to wrap info about a day of a month such as:
A
StringConverter capable of converting DayOfWeek to/from Strings.Enumerator which defines 6 levels of
DropShadow effects from LEVEL0 to LEVEL5.Extension of
NumberFilter for double fields.Implementation of
NumberRange to represent a Double range.Implementation of
NumberRangeProperty for Double ranges.Extension of
AbstractFilter for Enum fields.Implementation of
StringConverter to work with a generic Enum.Utility class which provides convenience methods for enumerators
Little utils class to convert a throwable stack trace to a String.
Utils class to help with concurrency and callables.
A simple bean that has all the necessary information to produce a
Predicate
for a given T object type.Extension of
NumberFilter for float fields.Implementation of
NumberRange to represent a Float range.Implementation of
NumberRangeProperty for Float ranges.A functional alternative to
StringConverter.Simply an
ObjectProperty that wraps a Function.Convenience class that offers some methods useful on combination with Java
Stream
to collect to JavaFX's collections.Implementation of a dynamic matrix in Java.
Enumeration used by
ObservableGrid.Change to specify the type of change.Convenience class to build
Insets objects.Extension of
NumberFilter for integer fields.Implementation of
NumberRange to represent an Integer range.Implementation of
NumberRangeProperty for Integer ranges.Enumerator that offers some new
Interpolators for JavaFX's animations.RippleGenerators only accept ripple types that implement this interface.
Public API for every ripple generator.
Helper class to process
ListChangeListener.Changes in a list of items of type T.Bean that contains:
Enumerator to represent the various types of
ListChangeListener.ChangesEnumerator to define the level of caching used by
MFXLoader.Utils class to load FXML views.
Extension of
NumberFilter for long fields.Implementation of
NumberRange to represent a Long range.Implementation of
NumberRangeProperty for Long ranges.Simple implementation of a Memoizer.
Concrete implementation of
AbstractMFXRippleGenerator<MFXCircleRippleGenerator.CircleRipple>.Utility class which manages a preset number of
DropShadow effects ordered by DepthLevel, but
it also allows to create custom DropShadow effects with MFXDepthManager.shadowOf(Color, double, double, double, double).Convenience class for creating icons wrapped in a StackPane.
Convenience class for creating dashboards, no more hassle on managing multiple views.
Support bean for
MFXLoader to define the properties of a view such as:From Google's material design guidelines:
A basic implementation of a validator in JavaFX.
A particular type of
Transition that follows the laws of the UAM (Uniformly Accelerated Motion)
to animate a target and make it look like it is decelerating towards the end of the animation.A
StringConverter capable of converting Month to/from Strings.Extension of
AbstractFilter, still abstract, limits the U parameter to Numbers.Base class to represent a range of numbers between a min and a max.
Simply an
ObjectProperty that wraps a NumberRange.Utils class for working with numbers.
Extension of
Grid to provide observables capabilities.Bean used to represent any type of change occurring in a
ObservableGrid data structure.A crude implementation of an observable stack It includes the main features of a stack namely:
push and pop.
Concrete implementation of
When that uses ChangeListeners to
listen for changes for a given ObservableValue.Concrete implementation of
When that uses InvalidationListeners to
listen for changes for a given ObservableValue.Simple bean that keeps track of two coordinates, x and y.
This is an extension of
PositionBean to be used
with Transitions that start from a point P(x, y) and
end at a point P1(endX, endY).Utilities for JavaFX's
Pos.Simply an
ObjectProperty that wraps a Predicate.Convenience methods for predicates.
Convenience methods related to properties.
Set of utilities for random ops.
A
SimpleBooleanProperty that implements ResettableProperty.A
SimpleDoubleProperty that implements ResettableProperty.A
SimpleFloatProperty that implements ResettableProperty.A
SimpleIntegerProperty that implements ResettableProperty.A
SimpleLongProperty that implements ResettableProperty.A
SimpleObjectProperty that implements ResettableProperty.Base interface for all resettable properties.
A
SimpleStringProperty that implements ResettableProperty.This class wraps a
ScheduledExecutorService to make it reusable by keeping
a reference to the ScheduledFuture.Convenience class for building Ripple clip shapes.
Deprecated.
Utility class for JavaFX's ScrollPanes.
Enumeration to indicate the severity of an
unmet
Constraint.This bean contains two
DoubleProperty to keep track/specify the sizes of something
in terms of width and height.Class used in various controls as a workaround for showing a node two or more times on the scene graph.
Extension of
AbstractFilter for String fields.Utils class for
Strings.Simply an
ObjectProperty that wraps a Supplier.Class copied from javafx.embed.swing to avoid adding the Swing module.
Implementation of
SynchronizedProperty for boolean values.Implementation of
SynchronizedProperty for double values.Implementation of
SynchronizedProperty for float values.Implementation of
SynchronizedProperty for integer values.Implementation of
SynchronizedProperty for long values.Implementation of
SynchronizedProperty for generic values.Helper class to avoid code duplication.
Implementation of
SynchronizedProperty for String values.Utils class for JavaFX's
Labels and MFXLabels.Utils class for
ToggleButtons.A
TransformableList is a particular type of List which wraps another
List called "source" and allows manipulations such as: filter and sort, retaining
the original items' index.For some idiot reason JavaFX's
TransformationLists do not allow modifying the
source list.Represents an operation that accepts three input arguments and returns no
result.
Simply an
ObjectProperty that wraps a TriConsumer.Interface that defines the public API every control needing validation
should implement.
Useful class to listen to changes for a given
ObservableValue and perform any
specified action when it changes.